From d6744d7fee6a78a20759c7a61dbc9a118cc21c78 Mon Sep 17 00:00:00 2001
From: Mario Martelli <cocoa@schnuddelhuddel.de>
Date: Wed, 28 Jun 2017 16:36:45 +0200
Subject: [PATCH] org-protocol.el sources with date URL are supported

* (org-protocol-project-alist): date-URL is added as example
* (org-protocol-open-source): first match is processed in rewrite
* (test-org-protocol/org-protocol-open-source): configuration
displaying a date-style URL is added

TINYCHANGE
---
 lisp/org-protocol.el              | 16 +++++++++++++---
 testing/lisp/test-org-protocol.el |  6 ++++++
 2 files changed, 19 insertions(+), 3 deletions(-)

diff --git a/lisp/org-protocol.el b/lisp/org-protocol.el
index cd4b216aa..099e7e25d 100644
--- a/lisp/org-protocol.el
+++ b/lisp/org-protocol.el
@@ -194,7 +194,14 @@ Example:
           :working-suffix \".org\"
           :base-url \"http://localhost/org/\"
           :working-directory \"/home/user/org/\"
-          :rewrites ((\"org/?$\" . \"index.php\")))))
+          :rewrites ((\"org/?$\" . \"index.php\")))
+         (\"Hugo based blog\"
+          :base-url \"https://www.site.com/\"
+          :working-directory \"~/site/content/post/\"
+          :online-suffix \".html\"
+          :working-suffix \".md\"
+          :rewrites ((\"\\(https://site.com/[0-9]+/[0-9]+/[0-9]+/\\)\" . \".md\")))))
+
 
    The last line tells `org-protocol-open-source' to open
    /home/user/org/index.php, if the URL cannot be mapped to an existing
@@ -556,8 +563,11 @@ The location for a browser's bookmark should look like this:
 		      ;; Try to match a rewritten URL and map it to
 		      ;; a real file.  Compare redirects without
 		      ;; suffix.
-		      (when (string-match-p (car rewrite) f1)
-			(throw 'result (concat wdir (cdr rewrite))))))))
+	      	      (when (string-match (car rewrite) f1)
+			(let ((replacement (concat
+					    (directory-file-name  (replace-match "" nil nil f1 1))
+					    (cdr rewrite))))
+			  (throw 'result (concat wdir replacement))))))))
 	      ;; -- end of redirects --
 
               (if (file-readable-p the-file)
diff --git a/testing/lisp/test-org-protocol.el b/testing/lisp/test-org-protocol.el
index 8f946864c..b11c72a68 100644
--- a/testing/lisp/test-org-protocol.el
+++ b/testing/lisp/test-org-protocol.el
@@ -137,6 +137,12 @@
 	     :base-url "http://another.example.com/"
 	     :online-suffix ".js"
 	     :working-directory ,(file-name-directory temp-file-name2))
+	    (test3
+	     :base-url "https://blog-example.com/"
+	     :working-directory ,(file-name-directory temp-file-name2))
+	     :online-suffix ".html"
+	     :working-suffix ".md"
+	     :rewrites (("\\(https://blog-example.com/[0-9]+/[0-9]+/[0-9]+/\\)" . ".md"))
 	    ))
 	 (test-cases
 	  (list
-- 
2.11.0 (Apple Git-81)

